scipy.spatial.Delaunay
======================

.. currentmodule:: scipy.spatial

.. autoclass:: Delaunay

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Delaunay.__init__
         Delaunay.find_simplex
         Delaunay.lift_points
         Delaunay.plane_distance



   

   .. HACK
      .. autosummary::
         :toctree:
      
         Delaunay.convex_hull
         Delaunay.transform
         Delaunay.vertex_to_simplex

